==> side_menu_v3.3.1.zip: side_menu/l10n/de.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Benutzerdefiniertes Menü",
    "Enable the custom menu": "Benutzerdefiniertes Menü aktivieren",
    "No": "Nein",
    "Yes": "Ja",
    "Menu": "Menü",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Verwende die Tastenkombination <span class=\"keyboard-key\">Strg<\/span>+<span class=\"keyboard-key\">o<\/span>, um das Seitenmenü ein- und auszublenden. Verwende <span class=\"keyboard-key\">tab<\/span> zum Navigieren.",
    "Top menu": "Obere Navigationsleiste",
    "Apps that not must be moved in the side menu": "Anwendungen, die nicht ins Seitenmenü verschoben werden sollen",
    "If there is no selection then the global configuration is applied.": "Wenn keine Auswahl vorhanden ist, wird die globale Konfiguration angewendet.",
    "Experimental": "Experimentell",
    "Save": "Speichern",
    "You like this app and you want to support me?": "Du magst diese Anwendung und möchtest mich unterstützen?",
    "Buy me a coffee ☕": "Gib mir einen Kaffee aus ☕",
    "Hidden": "Ausblenden",
    "Small": "Klein",
    "Normal": "Normal",
    "Big": "Groß",
    "Colors": "Farben",
    "Background color": "Hintergrundfarbe",
    "Background color of current app": "Hintergrundfarbe der aktuellen Anwendung",
    "Text color": "Textfarbe",
    "Loader": "Ladestandanzeige",
    "Icon": "Symbol",
    "Same color": "Selbe Farbe",
    "Opposite color": "Gegenfarbe",
    "Transparent": "Transparent",
    "Opaque": "Nicht transparent",
    "Opener": "Menü-Symbol",
    "Default": "Standard",
    "Default (dark)": "Standard (dunkel)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (dunkel)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (dunkel)",
    "Before the logo": "Vor dem Logo",
    "After the logo": "Nach dem Logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Nur das Menü-Symbol anzeigen (Logo wird ausgeblendet)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Zeige das Seitenmenü und das Menü-Symbol nicht an, wenn keine Anwendung vorhanden ist (z.B. bei öffentlichen Seiten).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Öffne das Menü, wenn die Maus über das Menü-Symbol bewegt wird (auf Touchscreens automatisch deaktiviert)",
    "Display the big menu": "Großes Menü anzeigen",
    "Display the logo": "Logo anzeigen",
    "Icons and texts": "Symbole und Texte",
    "Loader enabled": "Ladestandanzeige aktiviert",
    "Tips": "Tipps",
    "Always displayed": "Immer anzeigen",
    "This is the automatic behavior when the menu is always displayed.": "Dies ist das automatische Verhalten, wenn das Menü immer angezeigt wird.",
    "Not compatible with touch screens.": "Nicht kompatibel mit Touchscreens.",
    "Big menu": "Großes Menü",
    "Live preview": "Live-Vorschau",
    "Open apps in new tab": "Öffne Anwendungen in einem neuen Tab",
    "Use the global setting": "Verwende die globale Einstellung",
    "Use my selection": "Verwende meine Auswahl",
    "Show and hide the list of applications": "Ein- und Ausblenden der Anwendungsliste",
    "Use the avatar instead of the logo": "Avatar anstelle des Logos anzeigen",
    "You do not have permission to change the settings.": "Du hast keine Berechtigung, die Einstellungen dieser Anwendung zu ändern.",
    "Force this configuration to users": "Konfiguration für alle Benutzer erzwingen",
    "Export the configuration": "Konfiguration exportieren",
    "Purge the cache": "Cache leeren",
    "Show the link to settings": "Link zu den Einstellungen anzeigen",
    "The menu is enabled by default for users": "Das Menü ist standardmäßig für alle Benutzer aktiviert",
    "Except when the configuration is forced.": "Gilt nicht, wenn die Konfiguration erzwungen wird.",
    "Apps that should not be displayed in the menu": "Anwendungen, die nicht im Menü angezeigt werden sollen",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Kompatibel mit dem <code>großen Menü<\/code>.",
    "The logo is a link to the default app": "Das Logo ist ein Link zur Standard-App",
    "Others": "Andere",
    "Categories": "Kategorien",
    "Customize sorting": "Sortierung anpassen",
    "Order by": "Sortieren nach",
    "Name": "Name",
    "Customed": "Benutzerdefiniert",
    "Show and hide the list of categories": "Liste der Kategorien ein- und ausblenden",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Diese Optionen werden auf <code>Dark Theme<\/code> oder <code>Breeze Dark Theme<\/code> angewendet.",
    "Dark mode colors": "Farben für den dunklen Modus",
    "With categories": "Mit Kategorien",
    "Custom categories": "Benutzerdefinierte Kategorien",
    "Customize application categories": "Anwendungskategorien anpassen",
    "Reset to default": "Auf Standard zurücksetzen",
    "Hidden icon": "Verstecktes Symbol",
    "Small icon": "Kleines Symbol",
    "Normal icon": "Normales Symbol",
    "Big icon": "Große Ikone",
    "Hidden text": "Versteckter Text",
    "Small text": "Kleiner Text",
    "Normal text": "Normaler Text",
    "Big text": "Großer Text",
    "Applications": "Applications",
    "Applications kept in the top menu": "Applications kept in the top menu",
    "Applications kept in the top menu but also shown in side menu": "Applications kept in the top menu but also shown in side menu",
    "These applications must be selected in the previous option.": "These applications must be selected in the previous option."
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> side_menu_v3.10.1.zip: side_menu/l10n/de.js <==
OC.L10N.register("side_menu", {
    "Custom menu": "Benutzerdefiniertes Menü",
    "Enable the custom menu": "Benutzerdefiniertes Menü aktivieren",
    "No": "Nein",
    "Yes": "Ja",
    "Menu": "Menü",
    "Use the shortcut <span class=\"keyboard-key\">Ctrl<\/span>+<span class=\"keyboard-key\">o<\/span> to open and to hide the side menu. Use <span class=\"keyboard-key\">tab<\/span> to navigate.": "Verwende die Tastenkombination <span class=\"keyboard-key\">Strg<\/span>+<span class=\"keyboard-key\">o<\/span>, um das Seitenmenü ein- und auszublenden. Verwende <span class=\"keyboard-key\">tab<\/span> zum Navigieren.",
    "Top menu": "Obere Navigationsleiste",
    "Apps that not must be moved in the side menu": "Anwendungen, die nicht ins Seitenmenü verschoben werden sollen",
    "If there is no selection then the global configuration is applied.": "Wenn keine Auswahl vorhanden ist, wird die globale Konfiguration angewendet.",
    "Experimental": "Experimentell",
    "Save": "Speichern",
    "You like this app and you want to support me?": "Du magst diese Anwendung und möchtest mich unterstützen?",
    "Buy me a coffee ☕": "Gib mir einen Kaffee aus ☕",
    "Hidden": "Ausblenden",
    "Small": "Klein",
    "Normal": "Normal",
    "Big": "Groß",
    "Colors": "Farben",
    "Background color": "Hintergrundfarbe",
    "Background color of current app": "Hintergrundfarbe der aktuellen Anwendung",
    "Text color": "Textfarbe",
    "Loader": "Ladestandanzeige",
    "Icon": "Symbol",
    "Same color": "Selbe Farbe",
    "Opposite color": "Gegenfarbe",
    "Transparent": "Transparent",
    "Opaque": "Nicht transparent",
    "Opener": "Menü-Symbol",
    "Default": "Standard",
    "Default (dark)": "Standard (dunkel)",
    "Hamburger": "Hamburger",
    "Hamburger (dark)": "Hamburger (dunkel)",
    "Hamburger 2": "Hamburger 2",
    "Hamburger 2 (dark)": "Hamburger 2 (dunkel)",
    "Before the logo": "Vor dem Logo",
    "After the logo": "Nach dem Logo",
    "Position": "Position",
    "Show only the opener (hidden logo)": "Nur das Menü-Symbol anzeigen (Logo wird ausgeblendet)",
    "Do not display the side menu and the opener if there is no application (eg: public pages).": "Zeige das Seitenmenü und das Menü-Symbol nicht an, wenn keine Anwendung vorhanden ist (z.B. bei öffentlichen Seiten).",
    "Panel": "Panel",
    "Open the menu when the mouse is hover the opener (automatically disabled on touch screens)": "Öffne das Menü, wenn die Maus über das Menü-Symbol bewegt wird (auf Touchscreens automatisch deaktiviert)",
    "Display the big menu": "Großes Menü anzeigen",
    "Display the logo": "Logo anzeigen",
    "Icons and texts": "Symbole und Texte",
    "Loader enabled": "Ladestandanzeige aktiviert",
    "Tips": "Tipps",
    "Always displayed": "Immer anzeigen",
    "This is the automatic behavior when the menu is always displayed.": "Dies ist das automatische Verhalten, wenn das Menü immer angezeigt wird.",
    "Not compatible with touch screens.": "Nicht kompatibel mit Touchscreens.",
    "Big menu": "Großes Menü",
    "Live preview": "Live-Vorschau",
    "Open apps in new tab": "Öffne Anwendungen in einem neuen Tab",
    "Use the global setting": "Verwende die globale Einstellung",
    "Use my selection": "Verwende meine Auswahl",
    "Show and hide the list of applications": "Ein- und Ausblenden der Anwendungsliste",
    "Use the avatar instead of the logo": "Avatar anstelle des Logos anzeigen",
    "You do not have permission to change the settings.": "Du hast keine Berechtigung, die Einstellungen dieser Anwendung zu ändern.",
    "Force this configuration to users": "Konfiguration für alle Benutzer erzwingen",
    "Export the configuration": "Konfiguration exportieren",
    "Purge the cache": "Cache leeren",
    "Show the link to settings": "Link zu den Einstellungen anzeigen",
    "The menu is enabled by default for users": "Das Menü ist standardmäßig für alle Benutzer aktiviert",
    "Except when the configuration is forced.": "Gilt nicht, wenn die Konfiguration erzwungen wird.",
    "Apps that should not be displayed in the menu": "Anwendungen, die nicht im Menü angezeigt werden sollen",
    "This feature is only compatible with the <code>big menu<\/code> display.": "Kompatibel mit dem <code>großen Menü<\/code>.",
    "The logo is a link to the default app": "Das Logo ist ein Link zur Standard-App",
    "Others": "Andere",
    "Categories": "Kategorien",
    "Customize sorting": "Sortierung anpassen",
    "Order by": "Sortieren nach",
    "Name": "Name",
    "Customed": "Benutzerdefiniert",
    "Show and hide the list of categories": "Liste der Kategorien ein- und ausblenden",
    "This parameters are used when Dark theme or Breeze Dark Theme are enabled.": "Diese Optionen werden auf <code>Dark Theme<\/code> oder <code>Breeze Dark Theme<\/code> angewendet.",
    "Dark mode colors": "Farben für den dunklen Modus",
    "With categories": "Mit Kategorien",
    "Custom categories": "Benutzerdefinierte Kategorien",
    "Customize application categories": "Anwendungskategorien anpassen",
    "Reset to default": "Auf Standard zurücksetzen",
    "Hidden icon": "Verstecktes Symbol",
    "Small icon": "Kleines Symbol",
    "Normal icon": "Normales Symbol",
    "Big icon": "Große Ikone",
    "Hidden text": "Versteckter Text",
    "Small text": "Kleiner Text",
    "Normal text": "Normaler Text",
    "Big text": "Großer Text",
    "Applications": "Anwendungen",
    "Applications kept in the top menu": "Applications kept in the top menu",
    "Applications kept in the top menu but also shown in side menu": "Applications kept in the top menu but also shown in side menu",
    "These applications must be selected in the previous option.": "These applications must be selected in the previous option.",
    "Hide labels on mouse over": "Hide labels on mouse over",
    "Except the hovered app": "Except the hovered app"
}, "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
